"""
Common aura functions
"""

import logging

from modules.base.config import ConfigReader


class AuraCommon:
    """
    AuraCommon handles logger, reads and stores config
    """
    logger = None
    config = None

    def __init__(self, logger=True):
        self.read_config()

        # create logger just once
        if logger:
            self.create_logger("AuraEngine")

    def read_config(self):
        """
        reads aura.ini
        :return:
        """
        self.config = ConfigReader()
        self.config.load_config()

    def create_logger(self, name):
        """
        Creates the logger instance for AuraEngine
        :param name: LoggerName
        :return:
        """
        lvl = self.config.get("loglevel")

        # create logger
        self.logger = logging.getLogger(name)
        self.logger.setLevel(lvl)

        # create file handler for logger
        file_handler = logging.FileHandler(self.config.get("logdir") + "/engine.log")
        file_handler.setLevel(lvl)

        # create stream handler for logger
        stream_handler = logging.StreamHandler()
        stream_handler.setLevel(lvl)

        # set format of log
        datepart = "%(asctime)s:%(name)s:%(levelname)s"
        message = " - %(message)s - "
        filepart = "[%(filename)s:%(lineno)s-%(funcName)s()]"
        formatter = logging.Formatter(datepart + message + filepart)
        file_handler.setFormatter(formatter)
        stream_handler.setFormatter(formatter)

        # add handlers to the logger
        self.logger.addHandler(file_handler)
        self.logger.addHandler(stream_handler)
